"""Top-level package for trclip."""

__author__ = """Yusuf ANI"""
__email__ = 'yusufani8@gmail.com'
__version__ = '0.1.18'
